@@ -19,14 +19,18 @@ from typing import Dict, Type
 from .base import ArtifactRegistryTransport
 from .grpc import ArtifactRegistryGrpcTransport
 from .grpc_asyncio import ArtifactRegistryGrpcAsyncIOTransport
+from .rest import ArtifactRegistryRestInterceptor, ArtifactRegistryRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[ArtifactRegistryTransport]]
 _transport_registry["grpc"] = ArtifactRegistryGrpcTransport
 _transport_registry["grpc_asyncio"] = ArtifactRegistryGrpcAsyncIOTransport
+_transport_registry["rest"] = ArtifactRegistryRestTransport
 
 __all__ = (
     "ArtifactRegistryTransport",
     "ArtifactRegistryGrpcTransport",
     "ArtifactRegistryGrpcAsyncIOTransport",
+    "ArtifactRegistryRestTransport",
+    "ArtifactRegistryRestInterceptor",
 )
